@@ -82,6 +82,8 @@ class DAVPrincipal extends Principal
    */
   private $unique_tag;
 
+  private $user_address_set;
+
   /**
   * Constructor
   * @param mixed $parameters If null, an empty Principal is created.  If it
@@ -205,6 +207,8 @@ class DAVPrincipal extends Principal
     // whom are we a proxy for? who is a proxy for us?
     // (as per Caldav Proxy section 5.1 Paragraph 7 and 5)
     $sql = 'SELECT principal_id, username, pprivs(:request_principal::int8,principal_id,:scan_depth::int) FROM principal JOIN usr USING(user_no) WHERE usr.active=true AND principal_id IN (SELECT * from p_has_proxy_access_to(:request_principal,:scan_depth))';
+    if ( isset($c->strict_result_ordering) && $c->strict_result_ordering ) $sql .= " ORDER BY username";
+
     $params = array( ':request_principal' => $this->principal_id, ':scan_depth' => $c->permission_scan_depth );
     $qry = new AwlQuery($sql, $params);
     if ( $qry->Exec('DAVPrincipal') && $qry->rows() > 0 ) {
@@ -224,6 +228,8 @@ class DAVPrincipal extends Principal
     $sql = 'SELECT principal_id, username, pprivs(principal_id,:request_principal::int8,:scan_depth::int) FROM principal JOIN usr USING(user_no) WHERE usr.active=true AND principal_id IN (SELECT * from grants_proxy_access_from_p(:request_principal,:scan_depth))';
      */
     $sql = 'SELECT principal_id, username, pprivs(principal_id,:request_principal::int8,:scan_depth::int) FROM principal JOIN usr USING(user_no) WHERE usr.active=true AND principal_id IN (SELECT to_principal FROM grants WHERE by_principal = :request_principal AND (privileges & 5::BIT(24)) != 0::BIT(24) AND by_collection IS NULL AND to_principal != :request_principal )';
+    if ( isset($c->strict_result_ordering) && $c->strict_result_ordering ) $sql .= " ORDER BY username";
+
     $qry = new AwlQuery($sql, $params ); // reuse $params assigned for earlier query
     if ( $qry->Exec('DAVPrincipal') && $qry->rows() > 0 ) {
       while( $relationship = $qry->Fetch() ) {
