@@ -78,7 +78,7 @@ function getPrincipalByID( $principal_id, $use_cache = true ) {
 * Creates some default home collections for the user.
 * @param string $username The username of the user we are creating relationships for.
 */
-function CreateHomeCollections( $username, $defult_timezone = null ) {
+function CreateHomeCollections( $username, $default_timezone = null ) {
   global $session, $c;
 
   if ( !isset($c->default_collections) )
@@ -86,9 +86,27 @@ function CreateHomeCollections( $username, $defult_timezone = null ) {
     $c->default_collections = array();
 
     if( !empty($c->home_calendar_name) )
-      $c->default_collections[] = array( 'type' => 'calendar', 'name' => $c->home_calendar_name );
+      $c->default_collections[] = array(
+        'type' => 'calendar',
+        'name' => $c->home_calendar_name
+      );
+    if( !empty($c->home_out_calendar_name) )
+      $c->default_collections[] = array(
+        'type'               => 'calendar',
+        'name'               => $c->home_out_calendar_name,
+        'displayname_suffix' => ' Outbox'
+      );
+    if( !empty($c->home_in_calendar_name) )
+      $c->default_collections[] = array(
+        'type'               => 'calendar',
+        'name'               => $c->home_in_calendar_name,
+        'displayname_suffix' => ' Inbox'
+      );
     if( !empty($c->home_addressbook_name) )
-      $c->default_collections[] = array( 'type' => 'addressbook', 'name' => $c->home_addressbook_name );
+      $c->default_collections[] = array(
+        'type' => 'addressbook',
+        'name' => $c->home_addressbook_name
+      );
   }
 
   if ( !is_array($c->default_collections) || !count($c->default_collections) ) return true;
@@ -118,7 +136,13 @@ function CreateHomeCollections( $username, $defult_timezone = null ) {
           $params[':parent_container'] = $principal->dav_name();
           $params[':dav_etag'] = '-1';
           $params[':collection_path'] = $principal->dav_name().$v['name'].'/';
-          $params[':displayname'] = ( !isset($v['displayname']) || empty($v['displayname']) ? $user_fullname.( $v['type']=='calendar' ? ' calendar' : ' addressbook' ) : str_replace(array('%fn', '%rfn'), array($user_fullname, $user_rfullname), $v['displayname']) );
+          if ( isset($v['displayname']) && ! empty($v['displayname']) ) {
+              $params[':displayname'] = str_replace(array('%fn', '%rfn'), array($user_fullname, $user_rfullname), $v['displayname']);
+          } elseif ( isset($v['displayname_suffix']) && ! empty($v['displayname_suffix']) ) {
+              $params[':displayname'] = $user_fullname . $v['displayname_suffix'];
+          } else {
+              $params[':displayname'] = $user_fullname . ($v['type']=='calendar' ? ' calendar' : ' addressbook');
+          }
           $params[':resourcetypes'] = ( $v['type']=='calendar' ? '<DAV::collection/><urn:ietf:params:xml:ns:caldav:calendar/>' : '<DAV::collection/><urn:ietf:params:xml:ns:carddav:addressbook/>' );
           $params[':is_calendar'] = ( $v['type']=='calendar' ? true : false );
           $params[':is_addressbook'] = ( $v['type']=='addressbook' ? true : false );
@@ -126,7 +150,7 @@ function CreateHomeCollections( $username, $defult_timezone = null ) {
 
           $qry = new AwlQuery( $sql, $params );
           if ( $qry->Exec() ) {
-            $c->messages[] = i18n('Home '.( $v['type']=='calendar' ? 'calendar' : 'addressbook' ).' added.');
+            $c->messages[] = i18n('Home '.( $v['type']=='calendar' ? 'calendar' : 'addressbook' ).' added.') . " " . $v['name'];
             dbg_error_log("User",":Write: Created user's home ".( $v['type']=='calendar' ? 'calendar' : 'addressbook' )." at '%s'", $params[':collection_path'] );
 
             // create value for urn:ietf:params:xml:ns:caldav:supported-calendar-component-set property
@@ -231,6 +255,9 @@ function UpdateCollectionTimezones( $username, $new_timezone=null ) {
   if ( empty($new_timezone) ) return;
   $qry = new AwlQuery('UPDATE collection SET timezone=? WHERE dav_name LIKE ? AND is_calendar', '/'.$username.'/%', $new_timezone);
   $qry->Exec();
+
+  require_once("instance_range.php");
+  update_instance_ranges($dav_resource->dav_name());
 }
 
 /**
