@@ -21,8 +21,7 @@ if ( !$dav_resource->HavePrivilegeTo('DAV::write-properties') ) {
   }
 }
 
-$position = 0;
-$xmltree = BuildXMLTree( $request->xml_tags, $position);
+$xmltree = BuildXMLTree( $request->xml_tags );
 
 // echo $xmltree->Render();
 
