@@ -7,6 +7,9 @@ require_once('vCalendar.php');
 
 use PHPUnit\Framework\TestCase;
 
+$c = (object) array();
+$c->rrule_loop_limit = 100;
+
 // 1PM-2PM Monday-Thursday (only for one week), NZ time
 $base_cal = new vCalendar("BEGIN:VCALENDAR
 PRODID:-//Mozilla.org/NONSGML Mozilla Calendar V1.1//EN
