@@ -1,4 +1,5 @@
 <?php
+require_once("csrf_tokens.php");
 
 // Editor component for collections
 $editor = new Editor(translate('Collection'), 'collection');
@@ -16,12 +17,9 @@ $editor->AddAttribute('timezone', 'id', 'fld_timezone' );
 $editor->AddAttribute('schedule_transp', 'id', 'fld_schedule_transp' );
 $editor->AddAttribute('is_calendar', 'id', 'fld_is_calendar');
 $editor->AddAttribute('is_addressbook', 'id', 'fld_is_addressbook');
-$editor->AddAttribute('is_calendar', 'onclick', 'toggle_enabled(\'fld_is_calendar\',\'=fld_timezone\',\'=fld_schedule_transp\',\'!fld_is_addressbook\');');
-$editor->AddAttribute('is_addressbook', 'onclick', 'toggle_enabled(\'fld_is_addressbook\',\'!fld_is_calendar\');');
 
 $editor->AddField('use_default_privs','default_privileges IS NULL');
 $editor->AddAttribute('use_default_privs', 'id', 'fld_use_default_privs');
-$editor->AddAttribute('use_default_privs', 'onclick', 'toggle_visible(\'fld_use_default_privs\',\'!privileges_settings\');');
 
 $editor->AddField('ics_file', "''");
 $editor->AddAttribute('ics_file', 'title', translate('Upload an iCalendar file or VCard file to replace this collection.'));
@@ -63,6 +61,20 @@ if ( isset($privsql) ) {
   $privqry->Exec('admin-collection-edit',__LINE__,__FILE__);
   $permissions = $privqry->Fetch();
   $can_write_collection = ($session->AllowedTo('Admin') || (bindec($permissions->priv) & privilege_to_bits('DAV::bind')) );
+  if ( ! $c->list_everyone ) {
+    $can_read_collection = ($session->AllowedTo('Admin') || (bindec($permissions->priv) & privilege_to_bits('DAV::read')) );
+    if ( ! $can_read_collection ) {
+      dbg_error_log( 'LOG WARNING', 'Access to id "%s"/"%s" by user "%s" rejected.', $id, $collection_name, $session->username );
+      header('Location: index.php');
+      @ob_flush(); exit(0);
+    }
+  }
+}
+
+// Verify CSRF token
+if($_SERVER['REQUEST_METHOD'] === "POST" && !verifyCsrfPost()) {
+    $c->messages[] = i18n("A valid CSRF token must be provided");
+    $can_write_collection = false;
 }
 
 dbg_error_log('collection-edit', "Can write collection: %s", ($can_write_collection? 'yes' : 'no') );
@@ -91,7 +103,14 @@ if ( $can_write_collection && $editor->IsSubmit() ) {
   }
   else {
     $c->messages[] = i18n("Updating Collection.");
+
+    // We need to know whether to update_instance_ranges, which is an expensive
+    // operation we should only do if the collection timezone has been updated
+    $tzqry = new AwlQuery( "SELECT timezone FROM collection WHERE collection_id=:id", [ ":id" => $id ] );
+    $tzqry->Exec('collection-edit',__LINE__,__FILE__);
+    $old_tz = $tzqry->Fetch()->timezone;
   }
+
   if ( !$editor->Write() ) {
     $c->messages[] = i18n("Failed to write collection.");
     if ( $id > 0 ) $editor->GetRecord();
@@ -121,6 +140,13 @@ if ( $can_write_collection && $editor->IsSubmit() ) {
       $c->messages[] =  i18n('The file is not UTF-8 encoded, please check the error for more details.');
     }
   }
+
+  if ($editor->IsCreate() || $old_tz != $_POST['timezone']) {
+    dbg_error_log('collection-edit', 'Need to update instance ranges, this will take a while...');
+    require_once("instance_range.php");
+    update_instance_ranges($editor->Value('dav_name'));
+  }
+
   // Uncache anything to do with the collection
   $cache = getCacheInstance();
   $cache->delete( 'collection-'.$editor->Value('dav_name'), null );
@@ -149,6 +175,9 @@ if ( $editor->Available() ) {
 }
 else {
   $c->page_title = $editor->Title(translate('Create New Collection'));
+  $c->scripts[] = 'js/common.js';
+  $c->scripts[] = 'js/edit.js';
+  $c->scripts[] = 'js/collection-edit.js';
   $privs = decbin(privilege_to_bits($c->default_privileges));
   $editor->Assign('default_privileges', $privs);
   $editor->Assign('username', $principal->username());
@@ -190,7 +219,7 @@ $privilege_xlate = array(
 * @param dbrow $row The row object we read from the database.
 * @return string The formatted privileges.
 */
-function collection_privilege_format_function( $value, $column, $row ) {
+function collection_privilege_format_function( $value, $column = NULL, $row = NULL ) {
   global $privilege_xlate;
 
   $privs = bits_to_privilege($value, 'calendar');
@@ -241,15 +270,10 @@ $btn_ss = htmlspecialchars(translate('Schedule Send'));    $btn_ss_title = htmls
 
 if ($can_write_collection || ! $id > 0) {
   $privileges_row = <<<EOPRIV
-<input type="button" value="$btn_all" class="submit" title="$btn_all_title" onclick="toggle_privileges('default_privileges', 'all', 'form_editor_1');">
-<input type="button" value="$btn_rw" class="submit" title="$btn_rw_title"
- onclick="toggle_privileges('default_privileges', 'read', 'write-properties', 'write-content', 'bind', 'unbind', 'read-free-busy',
-                            'read-current-user-privilege-set', 'schedule-deliver-invite', 'schedule-deliver-reply', 'schedule-query-freebusy',
-                            'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );">
-<input type="button" value="$btn_read" class="submit" title="$btn_read_title"
- onclick="toggle_privileges('default_privileges', 'read', 'read-free-busy', 'schedule-query-freebusy', 'read-current-user-privilege-set' );">
-<input type="button" value="$btn_fb" class="submit" title="$btn_fb_title"
- onclick="toggle_privileges('default_privileges', 'read-free-busy', 'schedule-query-freebusy' );">
+<input type="button" value="$btn_all" class="submit" title="$btn_all_title" id="toggle_priv_default_privileges_all">
+<input type="button" value="$btn_rw" class="submit" title="$btn_rw_title" id="toggle_priv_default_privileges_rw">
+<input type="button" value="$btn_read" class="submit" title="$btn_read_title" id="toggle_priv_default_privileges_read">
+<input type="button" value="$btn_fb" class="submit" title="$btn_fb_title" id="toggle_priv_default_privileges_fb">
 <br>$privileges_set
 EOPRIV;
   $submit_row = '<tr> <th class="right"></th>                   <td class="left" colspan="2">##submit##</td> </tr>';
@@ -259,87 +283,10 @@ EOPRIV;
   $submit_row = '';
 }
 
+$csrf_field = getCsrfField();
 $id = $editor->Value('collection_id');
 $template = <<<EOTEMPLATE
 ##form##
-<script language="javascript">
-function toggle_privileges() {
-  var argv = toggle_privileges.arguments;
-  var argc = argv.length;
-
-  if ( argc < 2 ) {
-    return;
-  }
-  var match_me = argv[0];
-
-  var set_to = -1;
-  if ( argv[1] == 'all' ) {
-    var form = document.getElementById(argv[2]);
-    var fieldcount = form.elements.length;
-    var matching = '/^' + match_me + '/';
-    for (var i = 0; i < fieldcount; i++) {
-      var fieldname = form.elements[i].name;
-      if ( fieldname.match( match_me ) ) {
-        if ( set_to == -1 ) {
-          set_to = ( form.elements[i].checked ? 0 : 1 );
-        }
-        form.elements[i].checked = set_to;
-      }
-    }
-  }
-  else {
-    for (var i = 1; i < argc; i++) {
-      var f = document.getElementById( match_me + '_' + argv[i]);
-      if ( set_to == -1 ) {
-        set_to = ( f.checked ? 0 : 1 );
-      }
-      f.checked = set_to;
-    }
-  }
-}
-
-function toggle_enabled() {
-  var argv = toggle_enabled.arguments;
-  var argc = argv.length;
-
-  var fld_checkbox =  document.getElementById(argv[0]);
-
-  if ( argc < 2 ) {
-    return;
-  }
-
-  for (var i = 1; i < argc; i++) {
-    var fld_id = argv[i].substr(1);
-    var fld_logical = argv[i].substr(0,1);
-    var f = document.getElementById(fld_id);
-    if ( fld_logical == '=' )
-      f.disabled = !fld_checkbox.checked;
-    else
-      f.disabled = fld_checkbox.checked;
-  }
-}
-
-function toggle_visible() {
-  var argv = toggle_visible.arguments;
-  var argc = argv.length;
-
-  var fld_checkbox =  document.getElementById(argv[0]);
-
-  if ( argc < 2 ) {
-    return;
-  }
-
-  for (var i = 1; i < argc; i++) {
-    var block_id = argv[i].substr(1);
-    var block_logical = argv[i].substr(0,1);
-    var b = document.getElementById(block_id);
-    if ( block_logical == '!' )
-      b.style.display = (fld_checkbox.checked ? 'none' : '');
-    else
-      b.style.display = (!fld_checkbox.checked ? 'none' : '');
-  }
-}
-</script>
 <style>
 th.right, label.privilege {
   white-space:nowrap;
@@ -370,12 +317,8 @@ label.privilege {
  <tr> <th class="right">$prompt_description:</th>      <td class="left">##description.textarea.78x6##</td> </tr>
  $submit_row
 </table>
+$csrf_field
 </form>
-<script language="javascript">
-toggle_enabled('fld_is_calendar','=fld_timezone','=fld_schedule_transp','!fld_is_addressbook');
-toggle_enabled('fld_is_addressbook','!fld_is_calendar');
-toggle_visible('fld_use_default_privs','!privileges_settings');
-</script>
 
 EOTEMPLATE;
 
@@ -389,11 +332,20 @@ if ( $editor->Available() ) {
 
   $c->stylesheets[] = 'css/browse.css';
   $c->scripts[] = 'js/browse.js';
+  $c->scripts[] = 'js/common.js';
+  $c->scripts[] = 'js/edit.js';
+  $c->scripts[] = 'js/collection-edit.js';
 
 
   $grantrow = new Editor("Grants", "grants");
   $grantrow->SetSubmitName( 'savegrantrow' );
-  $grantrow->SetLookup( 'to_principal', 'SELECT principal_id, displayname FROM dav_principal WHERE principal_id NOT IN (SELECT member_id FROM group_member WHERE group_id = '.$id.') ORDER BY displayname' );
+  $limit_grantrow = '';
+  if ( ! $c->list_everyone ) {
+    if ( ! $session->AllowedTo( "Admin" ) ) {
+      $limit_grantrow = 'AND (principal_id = \''.$session->principal_id.'\' or principal_id in (select member_id from group_member where group_id in (select group_id from group_member where member_id = \''.$session->principal_id.'\')) or principal_id in (select group_id from group_member where member_id = \''.$session->principal_id.'\'))';
+    }
+  }
+  $grantrow->SetLookup( 'to_principal', 'SELECT principal_id, displayname FROM dav_principal WHERE principal_id NOT IN (SELECT member_id FROM group_member WHERE group_id = '.$id.') '.$limit_grantrow.' ORDER BY displayname' );
   if ( $can_write_collection ) {
     if ( $grantrow->IsSubmit() ) {
       $_POST['by_collection'] = $id;
@@ -439,20 +391,17 @@ if ( $editor->Available() ) {
     $orig_to_id = $row_data->to_principal;
     $form_id = $grantrow->Id();
     $form_url = preg_replace( '#&(edit|delete)_grant=\d+#', '', $_SERVER['REQUEST_URI'] );
+    $csrf_field = getCsrfField();
 
     $template = <<<EOTEMPLATE
 <form method="POST" enctype="multipart/form-data" id="form_$form_id" action="$form_url">
+  $csrf_field
   <td class="left" colspan="2"><input type="hidden" name="id" value="$id"><input type="hidden" name="orig_to_id" value="$orig_to_id">##to_principal.select##</td>
   <td class="left" colspan="2">
-<input type="button" value="$btn_all" class="submit" title="$btn_all_title" onclick="toggle_privileges('grant_privileges', 'all', 'form_$form_id');">
-<input type="button" value="$btn_rw" class="submit" title="$btn_rw_title"
- onclick="toggle_privileges('grant_privileges', 'read', 'write-properties', 'write-content', 'bind', 'unbind', 'read-free-busy',
-                            'read-current-user-privilege-set', 'schedule-deliver-invite', 'schedule-deliver-reply', 'schedule-query-freebusy',
-                            'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );">
-<input type="button" value="$btn_read" class="submit" title="$btn_read_title"
- onclick="toggle_privileges('grant_privileges', 'read', 'read-free-busy', 'schedule-query-freebusy', 'read-current-user-privilege-set' );">
-<input type="button" value="$btn_fb" class="submit" title="$btn_fb_title"
- onclick="toggle_privileges('grant_privileges', 'read-free-busy', 'schedule-query-freebusy' );">
+<input type="button" value="$btn_all" class="submit" title="$btn_all_title" id="toggle_priv_grant_privileges_all">
+<input type="button" value="$btn_rw" class="submit" title="$btn_rw_title" id="toggle_priv_grant_privileges_rw">
+<input type="button" value="$btn_read" class="submit" title="$btn_read_title" id="toggle_priv_grant_privileges_read">
+<input type="button" value="$btn_fb" class="submit" title="$btn_fb_title" id="toggle_priv_grant_privileges_fb">
 <br>$privileges_set
   <td class="center">##$submit_label.submit##</td>
 </form>
